Taika at bird sight
-------------------

Taika is a simple Static Content Generator, it can be a simple files processor or can be more
complex, if extensions are used. It aims to be simple and extensible, so if a user needs more
functionality can add it via extensions.

In the future, we want to offer a admin web GUI (and possibly another kind of GUI) built in
natively, without needing an extension. This though, is something that will come in the future.
